@@ -224,7 +224,7 @@ def client(destination_hexhash, configpath):
         destination_hash = bytes.fromhex(destination_hexhash)
     except:
         RNS.log("Invalid destination entered. Check your input!\n")
-        exit()
+        sys.exit(0)
 
     # We must first initialise Reticulum
     reticulum = RNS.Reticulum(configpath)
@@ -449,8 +449,7 @@ def link_established(link):
     # And set up a small job to check for
     # a potential timeout in receiving the
     # file list
-    thread = threading.Thread(target=filelist_timeout_job)
-    thread.setDaemon(True)
+    thread = threading.Thread(target=filelist_timeout_job, daemon=True)
     thread.start()
 
 # This job just sleeps for the specified
@@ -463,7 +462,7 @@ def filelist_timeout_job():
     global server_files
     if len(server_files) == 0:
         RNS.log("Timed out waiting for filelist, exiting")
-        os._exit(0)
+        sys.exit(0)
 
 
 # When a link is closed, we'll inform the
@@ -476,9 +475,8 @@ def link_closed(link):
     else:
         RNS.log("Link closed, exiting now")
     
-    RNS.Reticulum.exit_handler()
     time.sleep(1.5)
-    os._exit(0)
+    sys.exit(0)
 
 # When RNS detects that the download has
 # started, we'll update our menu state
@@ -602,4 +600,4 @@ if __name__ == "__main__":
 
     except KeyboardInterrupt:
         print("")
-        exit()
\ No newline at end of file
+        sys.exit(0)
\ No newline at end of file
